@@ -6,9 +6,9 @@ Type annotations for sagemaker-a2i-runtime service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_sagemaker_a2i_runtime.type_defs import DeleteHumanLoopRequestTypeDef
+    from mypy_boto3_sagemaker_a2i_runtime.type_defs import DeleteHumanLoopRequestRequestTypeDef
 
-    data: DeleteHumanLoopRequestTypeDef = {...}
+    data: DeleteHumanLoopRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -24,38 +24,38 @@ else:
 
 
 __all__ = (
-    "DeleteHumanLoopRequestTypeDef",
-    "DescribeHumanLoopRequestTypeDef",
-    "DescribeHumanLoopResponseResponseTypeDef",
+    "DeleteHumanLoopRequestRequestTypeDef",
+    "DescribeHumanLoopRequestRequestTypeDef",
+    "DescribeHumanLoopResponseTypeDef",
     "HumanLoopDataAttributesTypeDef",
     "HumanLoopInputTypeDef",
     "HumanLoopOutputTypeDef",
     "HumanLoopSummaryTypeDef",
-    "ListHumanLoopsRequestTypeDef",
-    "ListHumanLoopsResponseResponseTypeDef",
+    "ListHumanLoopsRequestRequestTypeDef",
+    "ListHumanLoopsResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
-    "StartHumanLoopRequestTypeDef",
-    "StartHumanLoopResponseResponseTypeDef",
-    "StopHumanLoopRequestTypeDef",
+    "StartHumanLoopRequestRequestTypeDef",
+    "StartHumanLoopResponseTypeDef",
+    "StopHumanLoopRequestRequestTypeDef",
 )
 
-DeleteHumanLoopRequestTypeDef = TypedDict(
-    "DeleteHumanLoopRequestTypeDef",
+DeleteHumanLoopRequestRequestTypeDef = TypedDict(
+    "DeleteHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
     },
 )
 
-DescribeHumanLoopRequestTypeDef = TypedDict(
-    "DescribeHumanLoopRequestTypeDef",
+DescribeHumanLoopRequestRequestTypeDef = TypedDict(
+    "DescribeHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
     },
 )
 
-DescribeHumanLoopResponseResponseTypeDef = TypedDict(
-    "DescribeHumanLoopResponseResponseTypeDef",
+DescribeHumanLoopResponseTypeDef = TypedDict(
+    "DescribeHumanLoopResponseTypeDef",
     {
         "CreationTime": datetime,
         "FailureReason": str,
@@ -102,14 +102,14 @@ HumanLoopSummaryTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListHumanLoopsRequestTypeDef = TypedDict(
-    "_RequiredListHumanLoopsRequestTypeDef",
+_RequiredListHumanLoopsRequestRequestTypeDef = TypedDict(
+    "_RequiredListHumanLoopsRequestRequestTypeDef",
     {
         "FlowDefinitionArn": str,
     },
 )
-_OptionalListHumanLoopsRequestTypeDef = TypedDict(
-    "_OptionalListHumanLoopsRequestTypeDef",
+_OptionalListHumanLoopsRequestRequestTypeDef = TypedDict(
+    "_OptionalListHumanLoopsRequestRequestTypeDef",
     {
         "CreationTimeAfter": Union[datetime, str],
         "CreationTimeBefore": Union[datetime, str],
@@ -121,14 +121,14 @@ _OptionalListHumanLoopsRequestTypeDef = TypedDict(
 )
 
 
-class ListHumanLoopsRequestTypeDef(
-    _RequiredListHumanLoopsRequestTypeDef, _OptionalListHumanLoopsRequestTypeDef
+class ListHumanLoopsRequestRequestTypeDef(
+    _RequiredListHumanLoopsRequestRequestTypeDef, _OptionalListHumanLoopsRequestRequestTypeDef
 ):
     pass
 
 
-ListHumanLoopsResponseResponseTypeDef = TypedDict(
-    "ListHumanLoopsResponseResponseTypeDef",
+ListHumanLoopsResponseTypeDef = TypedDict(
+    "ListHumanLoopsResponseTypeDef",
     {
         "HumanLoopSummaries": List["HumanLoopSummaryTypeDef"],
         "NextToken": str,
@@ -157,16 +157,16 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartHumanLoopRequestTypeDef = TypedDict(
-    "_RequiredStartHumanLoopRequestTypeDef",
+_RequiredStartHumanLoopRequestRequestTypeDef = TypedDict(
+    "_RequiredStartHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
         "FlowDefinitionArn": str,
         "HumanLoopInput": "HumanLoopInputTypeDef",
     },
 )
-_OptionalStartHumanLoopRequestTypeDef = TypedDict(
-    "_OptionalStartHumanLoopRequestTypeDef",
+_OptionalStartHumanLoopRequestRequestTypeDef = TypedDict(
+    "_OptionalStartHumanLoopRequestRequestTypeDef",
     {
         "DataAttributes": "HumanLoopDataAttributesTypeDef",
     },
@@ -174,22 +174,22 @@ _OptionalStartHumanLoopRequestTypeDef = TypedDict(
 )
 
 
-class StartHumanLoopRequestTypeDef(
-    _RequiredStartHumanLoopRequestTypeDef, _OptionalStartHumanLoopRequestTypeDef
+class StartHumanLoopRequestRequestTypeDef(
+    _RequiredStartHumanLoopRequestRequestTypeDef, _OptionalStartHumanLoopRequestRequestTypeDef
 ):
     pass
 
 
-StartHumanLoopResponseResponseTypeDef = TypedDict(
-    "StartHumanLoopResponseResponseTypeDef",
+StartHumanLoopResponseTypeDef = TypedDict(
+    "StartHumanLoopResponseTypeDef",
     {
         "HumanLoopArn": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-StopHumanLoopRequestTypeDef = TypedDict(
-    "StopHumanLoopRequestTypeDef",
+StopHumanLoopRequestRequestTypeDef = TypedDict(
+    "StopHumanLoopRequestRequestTypeDef",
     {
         "HumanLoopName": str,
     },
